An internal crate for the message and msg macros.
Prefer the elfo-macros crate if you don’t need to wrap macros.
Functions
- message_
impl - Implementation of the
#[message]macro. - msg_
impl - Implements the
msg!macro.
An internal crate for the message and msg macros.
Prefer the elfo-macros crate if you don’t need to wrap macros.
#[message] macro.msg! macro.